==> 1.5.1.tar.gz: ios/Classes/PlatformViews/VideoFeedViewFactory.swift <==
//
//  VideoFeedViewFactory.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2022/2/21.
//

import FireworkVideo
import Flutter
import Foundation

class VideoFeedViewFactory: NSObject, FlutterPlatformViewFactory {
    private var messenger: FlutterBinaryMessenger

    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }

    func create(
        withFrame frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?
    ) -> FlutterPlatformView {
        return VideoFeedContainerView(
            frame: frame,
            viewIdentifier: viewId,
            arguments: args,
            binaryMessenger: messenger)
    }

    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
        return FlutterStandardMessageCodec.sharedInstance()
    }
}

private class VideoFeedContainerView: NSObject, FlutterPlatformView, VideoFeedViewDelegate {
    private var _view: UIView
    var methodChannel: FlutterMethodChannel
    var videoFeed: VideoFeed!

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        let channelName = String(
            format: FWChannelName.fireworkVideoFeedModule.rawValue, arguments: [viewId])
        methodChannel = FlutterMethodChannel.init(name: channelName, binaryMessenger: messenger)

        _view = UIView()
        super.init()
        // iOS views can be created here
        createVideoFeedView(parentView: _view, args: args as? [String: AnyObject])
        setMethodCallHandler(methodChannel)
    }

    deinit {

    }

    func createVideoFeedView(parentView: UIView, args: [String: AnyObject]?) {
        videoFeed = VideoFeed()
        videoFeed.translatesAutoresizingMaskIntoConstraints = false
        videoFeed.delegate = self
        if let arguments = args {
            videoFeed.sourceType = RCTConvert.videoFeedSourceType(arguments["source"] as? String)
            if let channel = arguments["channel"] as? String {
                videoFeed.channel = channel
            }
            if let playlist = arguments["playlist"] as? String {
                videoFeed.playlist = playlist
            }
            if let playlistGroup = arguments["playlistGroup"] as? String {
                videoFeed.playlistGroup = playlistGroup
            }
            if let dynamicContentParameters = arguments["dynamicContentParameters"]
                as? [String: [String]] {
                videoFeed.dynamicContentParameters = dynamicContentParameters
            }
            videoFeed.mode = RCTConvert.videoFeedMode(arguments["mode"] as? String)
            videoFeed.feedViewConfig = JsonHelper.fromDictionary(
                arguments["videoFeedConfiguration"] as? [String: AnyObject],
                type: VideoFeedConfiguration.self)
            videoFeed.playerViewConfig = JsonHelper.fromDictionary(
                arguments["videoPlayerConfiguration"] as? [String: AnyObject],
                type: VideoPlayerConfiguration.self)
            videoFeed.adConfiguration = JsonHelper.fromDictionary(
                arguments["adConfiguration"] as? [String: AnyObject], type: AdConfiguration.self)
        }

        parentView.addSubview(videoFeed)
        let constraints = videoFeed.constraints(equalTo: parentView)
        NSLayoutConstraint.activate(
            constraints
        )
    }

    func setMethodCallHandler(_ channel: FlutterMethodChannel) {
        channel.setMethodCallHandler { [weak self] (call: FlutterMethodCall, result: @escaping FlutterResult) -> Void in
            switch call.method {
            case FWVideoFeedMethodName.setVideoFeedConfiguration.rawValue:
                self?.setVideoFeedConfiguration(call.arguments as? [String: AnyObject])
                result(nil)
            case FWVideoFeedMethodName.setVideoPlayerConfiguration.rawValue:
                self?.setVideoPlayerConfiguration(call.arguments as? [String: AnyObject])
                result(nil)
            case FWVideoFeedMethodName.refresh.rawValue:
                self?.videoFeed.refresh()
                result(nil)
            default:
                result(FlutterMethodNotImplemented)
            }
        }
    }

    func setVideoFeedConfiguration(_ config: [String: AnyObject]?) {
        videoFeed.feedViewConfig = JsonHelper.fromDictionary(
            config, type: VideoFeedConfiguration.self)
    }

    func setVideoPlayerConfiguration(_ config: [String: AnyObject]?) {
        videoFeed.playerViewConfig = JsonHelper.fromDictionary(
            config, type: VideoPlayerConfiguration.self)
    }

    // MARK: - FlutterPlatformView
    func view() -> UIView {
        return _view
    }

    // MARK: - VideoFeedViewDelegate
    func videoFeedDidLoadFeed(_ view: VideoFeed) {
        methodChannel.invokeMethod(
            VideoFeedEventName.onVideoFeedLoadFinished.rawValue, arguments: nil)
    }

    func videoFeed(_ view: VideoFeed, didFailToLoadFeed error: VideoFeedError) {
        methodChannel.invokeMethod(
            VideoFeedEventName.onVideoFeedLoadFinished.rawValue, arguments: error.jsObject)
    }
}

==> 2.0.4.tar.gz: ios/Classes/PlatformViews/VideoFeedViewFactory.swift <==
//
//  VideoFeedViewFactory.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2022/2/21.
//

import FireworkVideo
import Flutter
import Foundation

class VideoFeedViewFactory: NSObject, FlutterPlatformViewFactory {
    private var messenger: FlutterBinaryMessenger

    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }

    func create(
        withFrame frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?
    ) -> FlutterPlatformView {
        return VideoFeedContainerView(
            frame: frame,
            viewIdentifier: viewId,
            arguments: args,
            binaryMessenger: messenger)
    }

    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
        return FlutterStandardMessageCodec.sharedInstance()
    }
}

private class VideoFeedContainerView: NSObject, FlutterPlatformView, VideoFeedDelegate {
    private var _view: UIView
    var methodChannel: FlutterMethodChannel
    var videoFeed: VideoFeed!

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        _ = AppLanguageManager.shared

        let channelName = String(
            format: ChannelName.videoFeed.rawValue, arguments: [viewId])
        methodChannel = FlutterMethodChannel.init(name: channelName, binaryMessenger: messenger)

        _view = UIView()
        super.init()
        // iOS views can be created here
        createVideoFeedView(parentView: _view, args: args as? [String: AnyObject])
        setMethodCallHandler(methodChannel)
    }

    deinit {

    }

    func createVideoFeedView(parentView: UIView, args: [String: AnyObject]?) {
        videoFeed = VideoFeed()
        videoFeed.translatesAutoresizingMaskIntoConstraints = false
        videoFeed.delegate = self
        if let arguments = args {
            videoFeed.sourceType = Convert.videoFeedSourceType(arguments["source"] as? String)
            if let channel = arguments["channel"] as? String {
                videoFeed.channel = channel
            }
            if let playlist = arguments["playlist"] as? String {
                videoFeed.playlist = playlist
            }
            if let playlistGroup = arguments["playlistGroup"] as? String {
                videoFeed.playlistGroup = playlistGroup
            }
            if let dynamicContentParameters = arguments["dynamicContentParameters"]
                as? [String: [String]] {
                videoFeed.dynamicContentParameters = dynamicContentParameters
            }
            if let hashtagFilterExpression = arguments["hashtagFilterExpression"] as? String {
                videoFeed.hashtagFilterExpression = hashtagFilterExpression
            }
            videoFeed.mode = Convert.videoFeedMode(arguments["mode"] as? String)
            videoFeed.feedViewConfig = JsonHelper.fromDictionary(
                arguments["videoFeedConfiguration"] as? [String: AnyObject],
                type: VideoFeedConfiguration.self)
            videoFeed.playerViewConfig = JsonHelper.fromDictionary(
                arguments["videoPlayerConfiguration"] as? [String: AnyObject],
                type: VideoPlayerConfiguration.self)
            videoFeed.adConfiguration = JsonHelper.fromDictionary(
                arguments["adConfiguration"] as? [String: AnyObject], type: AdConfiguration.self)
            if let enablePictureInPicture = arguments["enablePictureInPicture"] as? Bool {
                videoFeed.enablePictureInPicture = enablePictureInPicture
            }
        }

        parentView.addSubview(videoFeed)
        let constraints = videoFeed.constraints(equalTo: parentView)
        NSLayoutConstraint.activate(
            constraints
        )
    }

    func setMethodCallHandler(_ channel: FlutterMethodChannel) {
        channel.setMethodCallHandler { [weak self] (call: FlutterMethodCall, result: @escaping FlutterResult) -> Void in
            switch call.method {
            case VideoFeedMethodName.setVideoFeedConfiguration.rawValue:
                self?.setVideoFeedConfiguration(call.arguments as? [String: AnyObject])
                result(nil)
            case VideoFeedMethodName.setVideoPlayerConfiguration.rawValue:
                self?.setVideoPlayerConfiguration(call.arguments as? [String: AnyObject])
                result(nil)
            case VideoFeedMethodName.refresh.rawValue:
                self?.videoFeed.refresh()
                result(nil)
            default:
                result(FlutterMethodNotImplemented)
            }
        }
    }

    func setVideoFeedConfiguration(_ config: [String: AnyObject]?) {
        videoFeed.feedViewConfig = JsonHelper.fromDictionary(
            config, type: VideoFeedConfiguration.self)
    }

    func setVideoPlayerConfiguration(_ config: [String: AnyObject]?) {
        videoFeed.playerViewConfig = JsonHelper.fromDictionary(
            config, type: VideoPlayerConfiguration.self)
    }

    // MARK: - FlutterPlatformView
    func view() -> UIView {
        return _view
    }

    // MARK: - VideoFeedViewDelegate
    func videoFeedDidLoadFeed(_ view: VideoFeed) {
        methodChannel.invokeMethod(
            VideoFeedEventName.onVideoFeedLoadFinished.rawValue, arguments: nil)
    }

    func videoFeed(_ view: VideoFeed, didFailToLoadFeed error: VideoFeedError) {
        methodChannel.invokeMethod(
            VideoFeedEventName.onVideoFeedLoadFinished.rawValue, arguments: error.jsObject)
    }
}
